package com.menlo.extras

import spock.lang.*

class Test_extras extends Specification {
	static String here = System.getProperty("user.dir")
	static String prog = "${here}/src/main/bash/extras"

	def "file does not exist"() {
		when:
			Process p = "${prog}".execute()
			p.waitFor()

		then:
			// Three ways to test, use whichever makes more sense to you

			// Explicit comparison
			new File("target/f1").exists() == false

			// Implied "truthiness"
			! new File("target/f1").exists()

			// Implied "truthiness" and explicit assertion
			assert ! new File("target/f1").exists()

		cleanup:
			new File("target/file2").delete()
			new File("target/file3").delete()
	}
	
	def "file exists, check size and contents"() {
		List<String> expected = [
			"Line 1",
			"Line two",
			"Line 3 3 3",
		]

		when:
			Process p = "${prog}".execute()
			p.waitFor()

		then:
			// Here's yet another form, better suited to multiple
			// tests on a single file

			// Create a file "handle"
			File f = new File("target/file2")

			// Check that the file exists
			f.exists()

			// Read and save the contents of the file
			List<String> got = []
			f.eachLine { line ->
				got << line
			}

			// Check the sizes
			got.size() == expected.size()

			// Compare the contents
			got == expected

		cleanup:
			new File("target/file2").delete()
			new File("target/file3").delete()
	}

	def "check file permissions"() {
		when:
			Process p = "${prog}".execute()
			p.waitFor()

		then:
			File f = new File("target/file3")

			// Tests only user bits; no portable way to check bits
			// for "group" or "other"
			f.canRead()
			f.canWrite()
			f.canExecute()

			// Here's a work-around
			Process ls = "ls -l target/file3".execute()
			ls.waitFor() == 0
			ls.text.startsWith("-rwxr-xr-x ")

		cleanup:
			new File("target/file2").delete()
			new File("target/file3").delete()
	}
} // Test_extras
